What is it?
==============

PyAstronomy (PyA) is a collection of astronomy related packages.

The aim of PyAstronomy is to provide a collection of packages, which fulfill
a certain standard both in code and documentation quality. 
In this way, we (the PyA group) want to ensure that PyA packages constitute
an enjoyable tool for enhancing the efficiency of our/your work and not
another source of painful experiences.

PyA emerged from the work of some people at the Hamburger Sternwarte. It has not
been designed to cover some particular field, but we integrated tools, which we
found useful during our work. Other people have different needs and also ours are
evolving. Therefore, we expect PyA to grow both by our own contributions
and, hopefully, contributions from others. 